@@ -2,7 +2,7 @@ from __future__ import absolute_import
 
 __author__ = """Pirtoaca George-Sebastian (sebisebi)"""
 __email__ = 'gpirtoaca@gmail.com'
-__version__ = '0.0.8'
+__version__ = '0.0.9'
 
 
 from .collection import Collection
@@ -26,3 +26,13 @@ def CSQA(*args, **kwargs):
 def ALLEN_AI_OBQA(*args, **kwargs):
     from data_mine.nlp.allen_ai_obqa import OBQADataset
     return OBQADataset(*args, **kwargs)
+
+
+def HOTPOT_QA(*args, **kwargs):
+    from data_mine.nlp.hotpot_qa import HotpotQADataset
+    return HotpotQADataset(*args, **kwargs)
+
+
+def COSMOS_QA(*args, **kwargs):
+    from data_mine.nlp.cosmos_qa import CosmosQADataset
+    return CosmosQADataset(*args, **kwargs)
